@@ -1,4 +1,5 @@
-from maitai_back.utils import misc_utils
+from betterproto import Casing
+
 from maitai_gen.config import Config, InferenceLocations, ModelConfig
 
 # TODO consider finding a source of truth where we don't need to deploy everytime a new model comes out
@@ -54,7 +55,7 @@ def get_default_config() -> Config:
 
 
 def reconcile_config_with_default(config_dict: dict) -> Config:
-    default_config_json = misc_utils.to_dict(get_default_config())
+    default_config_json = get_default_config().to_pydict(casing=Casing.SNAKE)
     for key, value in default_config_json.items():
         if key not in config_dict:
             config_dict[key] = value
@@ -81,4 +82,4 @@ def get_available_models():
         default_client_model=DEFAULT_CLIENT_MODEL,
         default_server_model=DEFAULT_SERVER_MODEL,
     )
-    return misc_utils.to_dict(model_config)
+    return model_config.to_pydict(casing=Casing.SNAKE)
